#ifndef %{APPNAMEUC}_H
#define %{APPNAMEUC}_H
#include "%{APPNAMELC}base.h"

class %{APPNAME} : public %{APPNAME}Base
{
    Q_OBJECT
  TQ_OBJECT

public:
    static TQString appName() {
        return TQString::tqfromLatin1("%{APPNAMELC}" );
    }
    %{APPNAME}( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~%{APPNAME}();

private slots:
    void goodBye();
};

#endif // %{APPNAMEUC}_H
